@@ -27,7 +27,8 @@ labels = {
     'MODEL_OUTPUT': "Model output value"
 }
 
-def waterfall(shap_values, max_display=10, show=True):
+# def waterfall(shap_values, max_display=10, show=True):
+def waterfall(base_value, shap_values = None, features = None, feature_names = None, max_display=10, show=True):
     """
     
     Parameters
@@ -42,15 +43,11 @@ def waterfall(shap_values, max_display=10, show=True):
         Whether matplotlib.pyplot.show() is called before returning. Setting this to False allows the plot
         to be customized further after it has been created.
     """
-    
 
-    base_values = shap_values.base_values
-    
-    features = shap_values.data
-    feature_names = shap_values.feature_names
+    base_values=base_value
     lower_bounds = getattr(shap_values, "lower_bounds", None)
     upper_bounds = getattr(shap_values, "upper_bounds", None)
-    values = shap_values.values
+    values = shap_values
 
     # make sure we only have a single output to explain
     if (type(base_values) == np.ndarray and len(base_values) > 0) or type(base_values) == list:
@@ -77,7 +74,7 @@ def waterfall(shap_values, max_display=10, show=True):
     # init variables we use for tracking the plot locations
     num_features = min(max_display, len(values))
     row_height = 0.5
-    rng = range(num_features - 1, -1, -1)
+    rng = range(num_features-1, -1, -1)
     order = np.argsort(-np.abs(values))
     pos_lefts = []
     pos_inds = []
@@ -94,7 +91,7 @@ def waterfall(shap_values, max_display=10, show=True):
     
     # size the plot based on how many features we are plotting
     pl.gcf().set_size_inches(8, num_features * row_height + 1.5)
-    # pl.rcParams['font.sans-serif'] = ['SimSun']
+    pl.rcParams['font.sans-serif']=['SimHei']  # 用来正常显示中文标签
 
     # see how many individual (vs. grouped at the end) features we are plotting
     if num_features == len(values):
@@ -180,7 +177,6 @@ def waterfall(shap_values, max_display=10, show=True):
                 xerr=np.array([[pos_widths[i] - pos_low[i]], [pos_high[i] - pos_widths[i]]]),
                 ecolor=colors.light_red_rgb
             )
-
         txt_obj = pl.text(
             pos_lefts[i] + 0.5*dist, pos_inds[i], format_value(pos_widths[i], '%+0.02f'),
             horizontalalignment='center', verticalalignment='center', color="white",
@@ -216,7 +212,6 @@ def waterfall(shap_values, max_display=10, show=True):
                 xerr=np.array([[neg_widths[i] - neg_low[i]], [neg_high[i] - neg_widths[i]]]),
                 ecolor=colors.light_blue_rgb
             )
-        
         txt_obj = pl.text(
             neg_lefts[i] + 0.5*dist, neg_inds[i], format_value(neg_widths[i], '%+0.02f'),
             horizontalalignment='center', verticalalignment='center', color="white",
